<?php
		@ini_set('display_errors', 'on');
		@ini_set('error_reporting', E_ALL); 
class Dotpay extends PaymentModule
{

	private	$_html = '';
	private $_postErrors = array();


	public function __construct()
	{
		$this->name = 'dotpay';
		$this->tab = 'Payment';
		$this->version = 0.1;

		parent::__construct();

		$this->page = basename(__FILE__, '.php');
		$this->displayName = $this->l('Dotpay');
		$this->description = $this->l('Akceptuje płatności przez serwis Dotpay');
	}

	public function getDotpayUrl()
	{
			return 'https://ssl.dotpay.pl/';
			
	}

	public function install()
	{
		if (!parent::install() OR !Configuration::updateValue('DOTPAY_ID', '')
			OR !Configuration::updateValue('DOTPAY_PIN', '')
			OR !$this->registerHook('payment') OR !$this->registerHook('paymentReturn'))
			return false;

		if (Validate::isInt(Configuration::get('PAYMENT_NEW_STATE')) XOR (Validate::isLoadedObject($order_state_new = new OrderState(Configuration::get('PAYMENT_NEW_STATE')))))
		{
			$order_state_new = new OrderState();
			$order_state_new->name[Language::getIdByIso("pl")] = "Rozpoczęcie płatności";
			$order_state_new->name[Language::getIdByIso("en")] = "Payment start";
			$order_state_new->send_email = false;
			$order_state_new->invoice = false;
			$order_state_new->unremovable = false;
			$order_state_new->color = "lightblue";
			if (!$order_state_new->add())
				return false;
			if(!Configuration::updateValue('PAYMENT_NEW_STATE', $order_state_new->id))
				return false;
		}
		return true;
	}

	public function uninstall()
	{
		if (!Configuration::deleteByName('DOTPAY_ID') OR !Configuration::deleteByName('DOTPAY_PIN')
			OR !parent::uninstall())
			return false;
		return true;
	}

	public function getContent()
	{
		$this->_html = '<h2>Dotpay</h2>';
		if (isset($_POST['submitDotpay']))
		{
			if (empty($_POST['dotpay_id']))
				$this->_postErrors[] = $this->l('Musisz podać Dotpay ID.');
			elseif (!Validate::isUnsignedInt($_POST['dotpay_id']))
				$this->_postErrors[] = $this->l('Dotpay ID musi być liczbą całkowitą.');
			if (!empty($_POST['dotpay_pin']) && !eregi('^[a-z0-9]{16}$', $_POST['dotpay_pin']))
				$this->_postErrors[] = $this->l('PIN musi składać się z 16 znaków alfanumerycznych.');

			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('DOTPAY_ID', intval($_POST['dotpay_id']));
				Configuration::updateValue('DOTPAY_PIN', $_POST['dotpay_pin']);
				$this->displayConf();
			}
			else
				$this->displayErrors();
		}

		$this->displayDotpay();
		$this->displayFormSettings();
		return $this->_html;
	}

	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Potwierdzenie').'" />
			'.$this->l('Ustawienia zapisane').'
		</div>';


	}

	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('Wystapily') : $this->l('Wystapil')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('bledy') : $this->l('blad')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}
	
	
	public function displayDotpay()
	{
		$this->_html .= '
		<img src="../modules/dotpay/dotpay.gif" style="float:left; margin-right:15px;" />
		<b>'.$this->l('Moduł pozwala na dokonywanie płatnosci przez Dotpay.').'</b><br /><br />
		'.$this->l('Przed użyciem modułu skonfiguruj swoje konto w Dotpay.').'
		<br /><br /><br />';
	}

	public function displayFormSettings()
	{
		$conf = Configuration::getMultiple(array('DOTPAY_ID', 'DOTPAY_PIN'));
		$dotpay_id = array_key_exists('dotpay_id', $_POST) ? $_POST['dotpay_id'] : (array_key_exists('DOTPAY_ID', $conf) ? $conf['DOTPAY_ID'] : '');
		$dotpay_pin = array_key_exists('dotpay_pin', $_POST) ? $_POST['dotpay_pin'] : (array_key_exists('DOTPAY_PIN', $conf) ? $conf['DOTPAY_PIN'] : '');

		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
		<fieldset class="width4">
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Ustawienia').'</legend>
			<label>'.$this->l('Twoj Dotpay ID').'</label>
			<div class="margin-form"><input type="text" size="10" name="dotpay_id" value="'.$dotpay_id.'" /></div>
			<label>'.$this->l('Twój PIN').'</label>
			<div class="margin-form"><input type="text" size="50" name="dotpay_pin" value="'.$dotpay_pin.'" /></div>
			<br /><center><input type="submit" name="submitDotpay" value="'.$this->l('Zapisz zmiany').'" class="button" /></center>
		</fieldset>
		</form><br /><br />
		<fieldset class="width4">
			<legend><img src="../img/admin/warning.gif" />'.$this->l('Informacje').'</legend>
			'.$this->l('Aby używac modułu Dotpay musisz skonfigurować konto w Dotpay.').'<br /><br />
			'.$this->l('Wybierz').' <i>'.$this->l('Ustawienia > Parametry URLC').'</i>, '.$this->l(' i ustaw:').'<br />
			<ul><li><b>'.$this->l('PIN taki sam jak w konfiguracji tego modułu. ').'</b> </li>			
			<li><b>'.$this->l('Adres URLC: ').'</b> '.' <code>http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'modules/'.$this->name.'/validation.php</code></li>	</ul>
		</fieldset>';
	}


	public function hookPayment($params)
	{
		global $smarty;
		$address = new Address(intval($params['cart']->id_address_invoice));
		$customer = new Customer(intval($params['cart']->id_customer));
		$dotpay_id = Configuration::get('DOTPAY_ID');


		if (!Validate::isUnsignedInt($dotpay_id))
			return $this->l('Blad platnosci: (nieprawidlowy Dotpay ID)');

		if (!Validate::isLoadedObject($address) OR !Validate::isLoadedObject($customer))
			return $this->l('Blad platnosci: (nieprawidlowy adres lub klient)');

		$cartproducts ='';
		foreach ($params['cart']->getProducts() as $product)
			$cartproducts.=$product['name'].',';
		$cartproducts = substr_replace($cartproducts,"",-1);

		$id_currency = intval(Configuration::get('PS_CURRENCY_DEFAULT'));
		$currency = new Currency(intval($id_currency));
		$id_lang = intval($params['cart']->id_lang);
		$lang = new Language($id_lang);

		$smarty->assign(array(
			'dotpayUrl' => $this->getDotpayUrl(),		
			'dotpay_id' => $dotpay_id,
			'amount' => number_format($params['cart']->getOrderTotal(),2,'.',''),
			'currency' => $currency->iso_code,
			'description' => 'Zakupy w sklepie '.Configuration::get('PS_SHOP_NAME'),
			'lang' => $lang->iso_code,
			'URL' => 'http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'modules/'.$this->name.'/order-confirmation.php',
			'URLC' => 'http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'modules/'.$this->name.'/validation.php', 
			'type' => 0,
			'txtguzik' => 'Powrót do '.Configuration::get('PS_SHOP_NAME'),
			'control' => intval($params['cart']->id),
			'customer' => $customer,
			'address' => $address,
			'country' => new Country(intval($address->id_country))
		));
		return $this->display(__FILE__, 'dotpay-form.tpl');
	}

	public function paymentReturn()
	{
		global $smarty;
		return $this->display(__FILE__, 'payment_return.tpl');
	}	

}

?>
